

#import <Cocoa/Cocoa.h>
#import <AddressBook/AddressBook.h>

extern NSString * const GoogleMapAddressNoName;
extern NSString * const GMAPhoneLabelKey;
extern NSString * const GMAPhoneNumberKey;



typedef enum 
{
	UnitedStatesAddress = 1,
	CanadaAddress = 2,
	UnitedKingdomAddress = 3,
	JapanAddress = 4,
	GermanyAddress = 5,
	FranceAddress = 6,
	SpainAddress = 7,
	ItalyAddress = 8,
	IrelandAddress = 9,
	UnknownAddress = 0
} AddressLocation;



@interface GoogleMapAddress : NSObject 
{
	ABPerson *person;
	NSString *addressIdentifier;
	NSString *addressLabel;
	
	// Address Fields
	NSString *street;
	NSString *city;
	NSString *state;
	NSString *zip;
	NSString *country;
	NSString *countryCode;
	
	NSString *firstName;	
	NSString *lastName;
	NSString *companyName;
	
	// Options that are specific to an address
	BOOL ignoreZipPlusFour;			// US
	BOOL ignorePostalCode;			// US, CA
	BOOL useOnlyPostalCode;			// UK
	BOOL ignoreStreetField;			// Japan = "futher divisions"
}


#pragma mark Address Functions

+(NSArray *)phoneNumbersForPerson:(ABPerson *)aPerson;
+(NSString *)defaultCountryCode;
+(NSString *)stripInvisibleCharacters:(NSString *)input;		// Strips illegal characters such as new lines, etc.
+(NSString *)createValidGoogleStringFrom:(NSString *)input;		// Returns URL-formated string

+(NSString *)encodedForURL:(NSString *)temp;

+(NSDictionary *)addressBookCountryList;
+(NSString *)countryForCountryCode:(NSString *)countryCode;

#pragma mark Address Options

+(void)setCharactersToIgnore:(NSArray *)stringArray;
-(void)setIgnoreZipPlusFour:(BOOL)yn;
-(void)setIgnorePostalCode:(BOOL)yn;
+(void)setIgnoreCountryField:(BOOL)yn;
-(void)setUseOnlyPostalCode:(BOOL)yn;
+(void)setApartmentLabels:(NSArray *)stringArray;
+(void)setUseNameAsLabel:(BOOL)yn;
-(void)setIgnoreStreetField:(BOOL)yn;
+(void)setAddPhoneNumbers:(BOOL)yn;
+(void)setNumberSeparator:(NSString *)separator;

#pragma mark Create New

+(GoogleMapAddress *)addressWithPerson:(ABPerson *)aPerson identifier:(NSString *)anIdentifier;
-(id)initWithPerson:(ABPerson *)aPerson identifier:(NSString *)anIdentifier;

#pragma mark Address Properties

-(int)nameDisplay;						// Returns kABShowAsPerson or kABShowAsCompany
-(NSString *)addressLabel;
-(NSString *)addressIdentifier;
-(NSString *)name;
-(NSString *)firstName;
-(NSString *)lastName;
-(NSString *)companyName;
-(NSString *)street;
-(NSString *)city;
-(NSString *)state;
-(NSString *)zip;
-(NSString *)country;
-(NSString *)countryCode;
//-(AddressLocation)postalCodeLocation;
-(AddressLocation)countryCodeLocation;
-(AddressLocation)determineLocation;	// Based on a combination of country code/ postal code

#pragma mark Address String

-(NSString *)addressString;					// What you would type in to the google field
-(NSString *)googleEncodedAddressString;	// Formatted for URL



@end








